<!--- Get the mail root directory from the registry.  The CFREGISTRY tag is
      discussed in Chapter 21, Working with the System Registry --->
<CFREGISTRY ACTION="GET"
      BRANCH="HKEY_LOCAL_MACHINE\SOFTWARE\Allaire\ColdFusion\CurrentVersion\Mail"
      ENTRY="BaseDirectory"
      VARIABLE="MailRoot"
      TYPE="String">

<!--- set the date trigger to 7, one week --->
<CFSET DateTrigger=7>
    
<!--- Read all of the files from the undeliverable directory for processing --->
<CFDIRECTORY Directory="#MailRoot#\undelivr"
             Name="Undeliverables">

<!--- Because of the . and .. listing in the directory, an empty directory 
      actually returns 2 for the record count.  Taking this into account, if the 
      record count is equal to 2, we know there are no files in the directory to 
      be moved.  If there are more than 2 records returned, we know that there 
      are files that either need to be moved or deleted. --->
<CFIF Undeliverables.RecordCount IS 2>
  <CFSET FilesMoved=0>
  <CFSET FilesDeleted=0>
  <CFSET MyQuery=QueryNew("FileName, FileSize, LastMod")> 
  <CFSET Temp=QueryAddRow(MyQuery)>
  <CFSET Temp=QuerySetCell(MyQuery, "FileName", "N/A", 1)>
  <CFSET Temp=QuerySetCell(MyQuery, "FileSize", "N/A", 1)>
  <CFSET Temp=QuerySetCell(MyQuery, "LastMod", "N/A", 1)>
<CFELSE>
  <!--- Set Constants --->
  <CFSET FilesMoved=0>
  <CFSET FilesDeleted=0>
  <CFSET FileName="">
  <CFSET FileSize="">
  <CFSET LastMod="">

  <!--- exclude . and .. as files --->
  <CFLOOP Query="Undeliverables">
    <CFIF Name is not "." and Name is not ".." and Type is "File">  

      <!--- Check to see if the last modified date of the file in the 
            undeliverable directory is older than the number of days specified in 
            the date trigger.  If it is, delete the file.  If the file is not 
            older, move it to the spool directory to be resent. --->

      <CFIF DateDiff("y", DateLastModified, Now()) GT DateTrigger>
  
        <CFFILE ACTION="Delete"
                FILE="#MailRoot#\undelivr\#NAME#">
        <CFSET FilesDeleted=FilesDeleted+1>
      <CFELSE>
        <CFFILE ACTION="move"
                SOURCE="#MailRoot#\undelivr\#NAME#"
                DESTINATION="#MailRoot#\spool\">
        <CFSET FilesMoved=FilesMoved+1>

        <CFOUTPUT>
        <CFSET FileName=ListAppend(FileName, Name, ",")>
        <CFSET FileSize=ListAppend(FileSize, Size, ",")>
        <CFSET LastMod=ListAppend(LastMod, DateLastModified, ",")>
        </CFOUTPUT>
      </CFIF>
    </CFIF>
  </CFLOOP>

  <!--- build the query to return  --->
  <CFSET #LenOfString#=#FilesMoved#>

  <CFIF #LenOfString# GTE 1>
    <CFSET MyQuery=QueryNew("FileName, FileSize, LastMod")> 
    <CFSET Temp=QueryAddRow(MyQuery, #LenOfString#)>
    <CFLOOP INDEX="ThisCol" FROM="1" TO="#LenOfString#">
      <CFSET Temp=QuerySetCell(MyQuery, "FileName", ListGetAt(FileName, 
      ThisCol), ThisCol)>
      <CFSET Temp=QuerySetCell(MyQuery, "FileSize", ListGetAt(FileSize, 
      ThisCol), ThisCol)>
      <CFSET Temp=QuerySetCell(MyQuery, "LastMod", ListGetAt(LastMod, 
      ThisCol), ThisCol)>
    </CFLOOP>

  <CFELSE>

    <CFSET MyQuery=QueryNew("FileName, FileSize, LastMod")> 
    <CFSET Temp=QueryAddRow(MyQuery)>
    <CFSET Temp=QuerySetCell(MyQuery, "FileName", "N/A", 1)>
    <CFSET Temp=QuerySetCell(MyQuery, "FileSize", "N/A", 1)>
    <CFSET Temp=QuerySetCell(MyQuery, "LastMod", "N/A", 1)>
  </CFIF>
</CFIF>

<CFIF FilesMoved GTE 1 OR FilesDeleted GTE 1>    

<CFMAIL QUERY="MyQuery"
        TO="you@yourdomain.com"
        FROM="webmaster@mydomain.com"
        SUBJECT="Undeliverable Mail Report">
Total Files Moved: #FilesMoved#
Total Files Deleted: #FilesDeleted#

These are the files affected:
<CFOUTPUT>
#FileName# (#filesize# bytes, #DateFormat(LastMod,'mm/dd/yyyy')#)
</CFOUTPUT>
</CFMAIL> 

</CFIF> 
